get.solutioncount <- function(lprec) {
  .Call(RlpSolve_get_solutioncount, lprec)
}
